%define version 2.0.9
%define auth_ldap_version 1.0.1

%define plugindir %_libdir/%name
%define buildldap 1

# There is an issue with gcc, so disable for amd64
# waiting reply/fix
%ifarch amd64
%define buildldap 0
%endif

Summary:	A Secure UDP Tunneling Daemon
Name:		openvpn
Version:	%version
Release:	%mkrel 4
URL:		http://openvpn.net/
Source0:	http://openvpn.net/release/%{name}-%{version}.tar.gz
Source1:    http://openvpn.net/signatures/%{name}-%{version}.tar.gz.asc
Source2:    http://www.opendarwin.org/~landonf/software/openvpn-auth-ldap/auth-ldap-%{auth_ldap_version}.tar.gz
Patch0:		%{name}-own-user.patch
Patch1:		openvpn-adding-routes.patch
Patch2:		openvpn-auth-ldap-1.0.patch
Patch3:		openvpn-2.0.5-pinit.patch
Patch4:     openvpn-2.1_rc1.openvpn_user.patch
License:	GPL
Group:		Networking/Other
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:  liblzo-devel openssl-devel
BuildRequires:	pam-devel
BuildRequires:  automake1.8
%if %buildldap
BuildRequires:  gcc-objc
BuildRequires:  openldap-devel
%endif
Requires(pre): rpm-helper
Requires(preun): rpm-helper
Requires(post): rpm-helper
Requires(postun): rpm-helper

%description
OpenVPN is a robust and highly flexible tunneling application that  uses
all of the encryption, authentication, and certification features of the
OpenSSL library to securely tunnel IP networks over a single UDP port.

%if buildldap
This package contains the auth-ldap plugin
%endif

%prep
%setup -q
%if %buildldap
%setup -q -a 2
%endif
%patch0 -p0
%patch1 -p1
%if %buildldap
%patch2 -p0
%endif
%patch3 -p1 -b .pinit
%patch4 -p1 -b .user

%build
%serverbuild
#./pre-touch
aclocal-1.8
automake-1.8
autoconf

CFLAGS="$RPM_OPT_FLAGS -fPIC" CCFLAGS="$RPM_OPT_FLAGS -fPIC"

%configure \
    --enable-pthread \
    --enable-plugin \
    --with-lzo-headers=%_includedir/lzo

%make

# plugins
%make -C plugin/down-root
%make -C plugin/auth-pam

%if %buildldap
%make -C auth-ldap-%auth_ldap_version OPENVPN=.. LDAP=/usr
%endif

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

#install -m755 %{name}.8 -D %{buildroot}%{_mandir}/man8/%{name}.8
#install -m755 %{name} -D %{buildroot}%{_sbindir}/%{name}
install -m755 sample-scripts/%{name}.init -D %{buildroot}/%{_initrddir}/%{name}
install -d %{buildroot}%{_sysconfdir}/%{name}

mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr easy-rsa sample-{config-file,key,script}s %{buildroot}%{_datadir}/%{name}

install -d $RPM_BUILD_ROOT%{_localstatedir}/%{name}

#plugins
mkdir -p %buildroot%plugindir

for pi in down-root auth-pam; do
    %__cp -f plugin/$pi/README plugin/README.$pi
    %__install -c -m 755 plugin/$pi/openvpn-$pi.so %{buildroot}%plugindir/openvpn-$pi.so
done

%if %buildldap
%__install -c -m 755 auth-ldap-%auth_ldap_version/openvpn-auth-ldap.so %{buildroot}%plugindir/openvpn-auth-ldap.so
%__cp -f auth-ldap-%auth_ldap_version/README auth-ldap-%auth_ldap_version/README-openvpn-auth-ldap
%endif

%clean
[ %{buildroot} != "/" ] && rm -rf %{buildroot}

%pre
%_pre_useradd %{name} %{_localstatedir}/%{name} /bin/true

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%defattr(-,root,root)
%doc AUTHORS INSTALL PORTS README
%doc plugin/README.*
%if %buildldap
%doc auth-ldap-%auth_ldap_version/README-openvpn-auth-ldap
%endif
%{_mandir}/man8/%{name}.8*
%{_sbindir}/%{name}
%{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}
%{_initrddir}/%{name}
%dir %{_localstatedir}/%{name}
%dir %plugindir
%plugindir/*.so




%changelog
* Wed Jan 23 2008 Thierry Vignaud <tvignaud@mandriva.com> 2.0.9-4mdv2008.1
+ Revision: 157261
- rebuild with fixed %%serverbuild macro

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 2.0.9-3mdv2008.1
+ Revision: 137470
- rebuilt against openldap-2.4.7 libs

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 2.0.9-2mdv2008.0
+ Revision: 45193
- using serverbuild macro (-fstack-protector-all)

* Wed May 09 2007 Olivier Thauvin <nanardon@mandriva.org> 2.0.9-1mdv2008.0
+ Revision: 25697
- 2.0.9
- don't bzip2 source, add gpg sig into source pkg


* Thu Mar 15 2007 Olivier Thauvin <nanardon@mandriva.org> 2.0.7-4mdv2007.1
+ Revision: 144578
- rebuild

* Wed Jan 31 2007 Olivier Thauvin <nanardon@mandriva.org> 2.1-0.rc2.2mdv2007.1
+ Revision: 115645
- merge patch no-user/group from 2.1 branches (Yves-Gwenael Bourhis)

* Sun Aug 13 2006 Olivier Thauvin <nanardon@mandriva.org> 2.0.7-2mdv2007.0
+ Revision: 55734
- rebuild
- add openvpn

* Thu Apr 20 2006 Olivier Thauvin <nanardon@mandriva.org> 2.0.7-1mdk
- 2.0.7

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 2.0.5-5mdk
- fix typo in initscript

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 2.0.5-4mdk
- convert parallel init to LSB

* Tue Jan 03 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.5-3mdk
- add parallel init support
- fix executable-marked-as-config-file
- be sure to wipe out buildroot at the beginning of %%install
- don't ship copyright notice as the package is GPL (see common-licenses)

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0.5-2mdk
- rebuilt against openssl-0.9.8a

* Thu Nov 10 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0.5-1mdk
- 2.0.5

* Mon Oct 17 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0.2-1mdk
- 2.0.2

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0.1-2mdk
- rebuilt against new openldap-2.3.6 libs

* Thu Aug 25 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0.1-1mdk
- 2.0.1
- ldap patch version 1.0.1
- remove patch3, fix upstream

* Sun Jul 10 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0-4mdk
- rebuild for lzo (#16777)
- add patch3: fix -lzo2 calls

* Thu Jun 23 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0-3mdk
- rebuild for lzo (Thanks Michar)

* Thu May 12 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0-2mdk
- Request by Luis Daniel Lucio Quiroz <dlucio@okay.com.mx>
  - add native plugin
  - add openvpn-auth-ldap plugin (except for amd64)

* Wed Apr 20 2005 Olivier Thauvin <nanardon@mandriva.org> 2.0-1mdk
- 2.0 final

* Fri Apr 08 2005 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.0-0.rc20.1mdk
- 2.0-rc20

* Thu Jan 13 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.6.0-2mdk
- rebuild
- cosmetics

* Tue Jun 01 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 1.6.0-1mdk
- 1.6.0
- fix buildrequires (lib64..)
- drop GPL license file, there's no reason for us to ship such common
  license files in packages, as we ship them with the common-licenses package!

